@@ -9,9 +9,11 @@
 #' @param con a PostgreSQL connection object
 #' @param tbl_main character name of the table that contains the 
 #' main time series catalog. Defaults to 'timeseries_main'.
+#' @param schema SQL schema name. Defaults to 'timeseries'.
 #' @export
 deleteTimeSeries <- function(series,con,
-                             tbl_main = 'timeseries_main'){
+                             tbl_main = 'timeseries_main',
+                             schema = 'timeseries'){
   sql_statement <- sprintf("DELETE FROM %s WHERE ts_key ='%s' CASCADE",
                            tbl_main, series)
   if(is.null(DBI::dbGetQuery(con,sql_statement))) sprintf('Time series %s deleted.',series)
